"""
Authors: Peter Mawhorter
Consulted:
Date: 2022-02-04
Purpose: Testing code for timeProfiler.py.
Tests only the functions that it can find defined, and makes a note of
those that it doesn't find.
"""

# The 'as' here allows us to create our own name for the module
import optimism as opt

import timeProfiler

# This file defines tests in such a way that if the function hasn't been
# defined yet, the tests will be skipped.


# Tests for inputFloat
testInputFloat = opt.testFunctionMaybe(timeProfiler, 'inputFloat')
pieCase = testInputFloat.case('What is pie? ')
pieCase.provideInputs('3.1415926')
pieCase.checkReturnValue(3.1415926)

sevenCase = testInputFloat.case('What rhymes with "heaven"? ')
sevenCase.provideInputs('7')
sevenCase.checkReturnValue(7.0)

smallCase = testInputFloat.case("What's below one? ")
smallCase.provideInputs('0.999')
smallCase.checkReturnValue(0.999)


# Tests for formatHours

testFormatHours = opt.testFunctionMaybe(timeProfiler, 'formatHours')
testFormatHours.case(10.0, 'work hours').checkReturnValue('10.0 work hours')
testFormatHours.case(3.111, 'hi').checkReturnValue('3.11 hi')
testFormatHours.case(3.999, 'up').checkReturnValue('4.0 up')

# Tests for indentMessage
testIndentMessage = opt.testFunctionMaybe(timeProfiler, 'indentMessage')
testIndentMessage.case('hello', 7).checkReturnValue('  hello')
testIndentMessage.case('hello', 5).checkReturnValue('hello')
testIndentMessage.case('hi', 5).checkReturnValue('   hi')

# Tests for createBar
testCreateBar = opt.testFunctionMaybe(timeProfiler, 'createBar')
testCreateBar.case('A', 7).checkReturnValue('AAAAAAA')
testCreateBar.case('B', 2.111).checkReturnValue('BB')
testCreateBar.case('C', 4.999).checkReturnValue('CCCCC')


# Tests for timeProfile
testTimeProfile = opt.testFunctionMaybe(timeProfiler, 'timeProfile')
valentinaCase = testTimeProfile.case()
valentinaCase.provideInputs("Latanya", "0", "8", "5", "2.5", "fun", "15")
valentinaCase.checkPrintedLines(
    'What is your name? Latanya',
    'How many hours do you work each week? 0',
    'How many hours per day do you sleep on average? 8',
    'How many classes are you taking this semester? 5',
    (
        'For one class, what is the average time spent in the classroom per'
        ' week? 2.5'
    ),
    "What shall we call the 'everything else' category? fun",
    "How many hours per week do you spend on 'fun'? 15",
    'Weekly time profile for Latanya:',
    '  0.0 work hours: ',
    '56.0 sleep hours: ' + 'S' * 56,
    '37.5 class hours: ' + 'C' * 38,
    '  15.0 fun hours: ' + 'E' * 15,
    ' 59.5 free hours: ' + 'F' * 60,
)

emmaCase = testTimeProfile.case()
emmaCase.provideInputs(
    "Alex", "8.5", "6.75", "4", "3.67", "extracurricular", "22.5"
)
emmaCase.checkPrintedLines(
    'What is your name? Alex',
    'How many hours do you work each week? 8.5',
    'How many hours per day do you sleep on average? 6.75',
    'How many classes are you taking this semester? 4',
    (
        'For one class, what is the average time spent in the classroom per'
        ' week? 3.67'
    ),
    "What shall we call the 'everything else' category? extracurricular",
    "How many hours per week do you spend on 'extracurricular'? 22.5",
    'Weekly time profile for Alex:',
    '            8.5 work hours: ' + 'W' * 8,
    '         47.25 sleep hours: ' + 'S' * 47,
    '         44.04 class hours: ' + 'C' * 44,
    '22.5 extracurricular hours: ' + 'E' * 22,
    '          45.71 free hours: ' + 'F' * 46,
)

# Note: this test case actually tests the rounding behavior, since it
# has inputs with more than 2 decimal places. The previous test cases
# don't test that!
exactCase = testTimeProfile.case()
exactCase.provideInputs(
    "Yuting", "2.999", "7.654", "4", "1.0001", "digits", "22.1234"
)
exactCase.checkPrintedLines(
    'What is your name? Yuting',
    'How many hours do you work each week? 2.999',
    'How many hours per day do you sleep on average? 7.654',
    'How many classes are you taking this semester? 4',
    (
        'For one class, what is the average time spent in the classroom per'
        ' week? 1.0001'
    ),
    "What shall we call the 'everything else' category? digits",
    "How many hours per week do you spend on 'digits'? 22.1234",
    'Weekly time profile for Yuting:',
    '    3.0 work hours: ' + 'W' * 3,
    ' 53.58 sleep hours: ' + 'S' * 54,
    '  12.0 class hours: ' + 'C' * 12,
    '22.12 digits hours: ' + 'E' * 22,
    '   77.3 free hours: ' + 'F' * 77,
)
